@@ -23,15 +23,14 @@
 from pwman.util.crypto import CryptoEngine
 
 
-class Tag(object):
+class Tag:  # pragma: no cover
     """
     tags are specific strings used to classify nodes
     the methods in this class override some built-ins
     for strings.
     """
     def __init__(self, name):
-        enc = CryptoEngine.get()
-        self._name = enc.encrypt(name)
+        self.set_name(name)
 
     def __eq__(self, other):
         if other._name == self._name:
@@ -39,6 +38,35 @@ class Tag(object):
         else:
             return False
 
+    def get_name(self):
+        enc = CryptoEngine.get()
+        return enc.decrypt(self._name)
+
+    def set_name(self, name):
+        enc = CryptoEngine.get()
+        self._name = enc.encrypt(name)
+
+    def __str__(self):
+        enc = CryptoEngine.get()
+        return enc.decrypt(self._name)
+
+
+class TagNew(object):
+
+    def __init__(self, name):
+        enc = CryptoEngine.get()
+        self._name = enc.encrypt(name)
+
+    def __eq__(self, other):  # pragma: no cover
+        if other._name == self._name:
+            return True
+        else:
+            return False
+
+    def __str__(self):
+        enc = CryptoEngine.get()
+        return enc.decrypt(self._name)
+
     @property
     def name(self):
         enc = CryptoEngine.get()
@@ -46,7 +74,5 @@ class Tag(object):
 
     @name.setter
     def name(self, value):
-        enc = CryptoEngine.get()
-        self._name = enc.encrypt(value)
-
-
+        enc = CryptoEngine.get()  # pragma: no cover
+        self._name = enc.encrypt(value)  # pragma: no cover
